
.. _user:

#################
PyEmir User Guide
#################

This guide is intended as an introductory overview of PyEmir and
explains how to install and make use of the most important features of
Pyemir. For detailed reference documentation of the functions and
classes contained in the package, see the :ref:`reference`.

.. warning::

   This "User Guide" is still a work in progress; some of the material
   is not organized, and several aspects of PyEmir are not yet covered
   sufficient detail.

.. toctree::
   :maxdepth: 2

   intro
   deploy
   recipes
